# htcondor-dags

[![Documentation Status](https://readthedocs.org/projects/htcondor-dags/badge/?version=latest)](https://htcondor-dags.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/htcondor/htcondor-dags.svg?branch=master)](https://travis-ci.org/htcondor/htcondor-dags)
[![codecov](https://codecov.io/gh/htcondor/htcondor-dags/branch/master/graph/badge.svg)](https://codecov.io/gh/htcondor/htcondor-dags)
